@@ -18,15 +18,23 @@ from django.conf import settings
 from django_drf_filepond.api import store_upload, get_stored_upload_file_data
 from django_drf_filepond.models import TemporaryUpload
 
-from .models import MediaGallery as Album, Video
-from photologue.models import Photo
+from .models import Album, Video, Photo
 
-CURRENT_SITE = Site.objects.get(id=settings.SITE_ID)
+
+def _generate_slug(title, obj):
+    slug_candidate = slug_original = slugify(title)
+    num_found = 0
+    for i in itertools.count(1):
+        if not obj.objects.filter(slug=slug_candidate).exists() and not Video.objects.filter(slug=slug_candidate).exists():
+            break
+        num_found+=1
+        slug_candidate = '{}-{}'.format(slug_original, i)
+    return slug_candidate, num_found
 
 class MediaForm(forms.Form):
     description = forms.CharField(label=_('Description'),
                                   required=False,
-                                  help_text=_('A description of this Gallery. Only required for new galleries.'))
+                                  help_text=_('A description of this Album. Only required for new albums.'))
 
     is_public = forms.BooleanField(label=_('Public'),
                                    initial=True,
@@ -36,26 +44,17 @@ class MediaForm(forms.Form):
     filepond = SimpleArrayField(forms.CharField(max_length=255), widget=forms.HiddenInput(),
            required=False)
 
-    def _generate_slug(self, title):
-        slug_candidate = slug_original = slugify(title)
-        num_found = 0
-        for i in itertools.count(1):
-            if not Photo.objects.filter(slug=slug_candidate).exists() and not Video.objects.filter(slug=slug_candidate).exists():
-                break
-            num_found+=1
-            slug_candidate = '{}-{}'.format(slug_original, i)
-        return slug_candidate, num_found
 
     def save(self, gallery):
         filelist = self.cleaned_data['filepond']
+        CURRENT_SITE = Site.objects.get(id=settings.SITE_ID)
 
-	# read list of filepond IDS which we will then import
-	# via store_upload from drf-filepond: https://tinyurl.com/3t3623b2
+        # read list of filepond IDS which we will then import
+        # via store_upload from drf-filepond: https://tinyurl.com/3t3623b2
         for upload_id in filelist:
             logger.debug('Reading file "{}".'.format(upload_id))
 
-            su = store_upload(upload_id,
-                    destination_file_path="photologue/{}".format(upload_id))
+            su = store_upload(upload_id, destination_file_path=upload_id)
 
             (filename, data) = get_stored_upload_file_data(su)
             if not len(data):
@@ -66,7 +65,7 @@ class MediaForm(forms.Form):
 
             # A photo might already exist with the same slug. So it's somewhat inefficient,
             # but we loop until we find a slug that's available.
-            slug, num_found = self._generate_slug(media_title_root)
+            slug, num_found = _generate_slug(media_title_root, Photo)
 
             if num_found > 0:
                 numbered_title = "{}({})".format(media_title_root, num_found)
@@ -74,19 +73,22 @@ class MediaForm(forms.Form):
             file_mimetype = magic.from_buffer(data, mime=True).split('/')[0]
             if file_mimetype  == 'image':
                 logger.info("image mimetype detected")
-                photo = Photo(title=numbered_title,
-                              slug=slug,
-                              is_public=self.cleaned_data['is_public'])
+                photo = Photo(
+                            title=numbered_title,
+                            slug=slug,
+                            is_public=self.cleaned_data['is_public'],
+                        )
 
-                photo.image = "photologue/{}".format(upload_id)
+                photo.src = "medialogue/{}".format(upload_id)
                 photo.save()
                 photo.sites.add(CURRENT_SITE)
                 gallery.photos.add(photo)
             elif file_mimetype == "video":
                 logger.info("video mimetype detected")
                 video = Video(title=numbered_title, slug=slug, is_public=self.cleaned_data['is_public'])
-                video.file = "photologue/{}".format(upload_id)
+                video.src = "medialogue/{}".format(upload_id)
                 video.save()
+                video.sites.add(CURRENT_SITE)
                 gallery.videos.add(video)
             else:
                 logger.error('cound not process file "{}"'.format(filename))
@@ -104,8 +106,10 @@ class NewAlbumForm(MediaForm):
         return gallery_title
 
     def save(self):
+        CURRENT_SITE = Site.objects.get(id=settings.SITE_ID)
+        slug, num_found = _generate_slug(self.cleaned_data['gallery_title'], Album)
         gallery = Album.objects.create(title=self.cleaned_data['gallery_title'],
-                                              slug=slugify(self.cleaned_data['gallery_title']),
+                                              slug=slug,
                                               description=self.cleaned_data['description'],
                                               is_public=self.cleaned_data['is_public'])
         gallery.sites.add(CURRENT_SITE)
@@ -113,8 +117,7 @@ class NewAlbumForm(MediaForm):
 
 class EditAlbumForm(MediaForm):
     gallery = forms.ModelChoiceField(Album.objects.all(),
-                                     label=_('Gallery'),
+                                     label=_('Album'),
                                      required=True,
                                      help_text=_('Select a gallery to add these images to. Leave this empty to '
                                                  'create a new gallery from the supplied title.'))
-
